============
Requirements
============

.. item:: SWRQT-SOME_RQT Some requirement

    A traceability item that gets validated by a robot test case that has the item ID in its tags.

.. item:: SWRQT-OTHER_RQT Another requirement

    Another traceability item.
